==> webStore_2.8.2_estable.zip: sincronizacion.php <==
<?php
/*
if ($fichero = fopen('/home/dpfevaristo/public_html/log.html', 'a+')){
	fputs($fichero, 'INICIO....');
	fclose($fichero);
}
*/

//Como todo esto lo vamos a hacer en cron, los log los vamos a echar a un fichero:
ob_start();

include_once('local.php');	// ==> Lo hacemos con un include para no tener que editar el index en cada cliente (Pedro 07/Febrero/2019)

//Nos aseguramos de que SIEMPRE exista un "core_path"
if (!defined('_WS_CORE_PATH')){
	define('_WS_CORE_PATH', '');	//Esta variable SÓLO se usa para poder hacer el include de webStore sin tener que tocar el index.php.
									//	Existe otra variable que es "_WS_CORE_DIR_" que contiene la ruta absoluta interna al core de webStore
}

//Arrancamos el core de webStore
include(_WS_CORE_PATH . 'core/initWebStore.php');


//Ahora vamos a cargar los ficheros de sincronización (la carpeta ahora se llama sincronización)
//include_once('sincronizacion/cargar_fichero_generico.php');
//include_once('sincronizacion/generar_ficheros_exportacion.php');
//include_once('sincronizacion/borrar_ficheros_antiguos.php');
/*
$contenido = ob_get_clean();
if ($fichero = fopen('/home/dpfevaristo/public_html/log.html', 'a+')){
	fputs($fichero, $contenido);
	fclose($fichero);
}
*/
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
    <head>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
        <title>Inserción de elementos</title>
    </head>
    <body>
		<p>Sincronización de elementos</p>
        <?php
		//Primero importamos
		$sincronizador = new ArmiSync(true);
		$sincronizador->fullImport();
		
		//Ahora viene la exportación
		//Nos empezamos asegurando de que los códigos de Sinlib de los clientes se propaguen a los pedidos
		PedidoCliente::associateEmptyClientsCode();
		//Ahora ejecutamos la exportación
		$sincronizador = new ArmiSync(true);
		//Indicamos el juego de caracteres de conversión
		$sincronizador->setEncodingOutput(array('UTF-8//IGNORE', 'ISO-8859-1'));
		//Primero de clientes
		$sincronizador->generar_fichero_usuario();
		//Ahora de pedidos
		echo("Tratamos de generar los ficheros de pedidos<br />\n");
		$sincronizador->generar_fichero_pedido();
		
		//Por último borramos ficheros antiguos
		ArmiSync::cleanOldFiles('finished/', 10);
		ArmiSync::cleanOldFiles('logs/', 10);
		
        ?>
    </body>
</html>

==> webStore_2.8.9_estable.zip: sincronizacion.php <==
<?php
/*
if ($fichero = fopen('/home/dpfevaristo/public_html/log.html', 'a+')){
	fputs($fichero, 'INICIO....');
	fclose($fichero);
}
*/

//Como todo esto lo vamos a hacer en cron, los log los vamos a echar a un fichero:
ob_start();

include_once('local.php');	// ==> Lo hacemos con un include para no tener que editar el index en cada cliente (Pedro 07/Febrero/2019)

//Nos aseguramos de que SIEMPRE exista un "core_path"
if (!defined('_WS_CORE_PATH')){
	define('_WS_CORE_PATH', '');	//Esta variable SÓLO se usa para poder hacer el include de webStore sin tener que tocar el index.php.
									//	Existe otra variable que es "_WS_CORE_DIR_" que contiene la ruta absoluta interna al core de webStore
}

//Arrancamos el core de webStore
include(_WS_CORE_PATH . 'core/initWebStore.php');


//Ahora vamos a cargar los ficheros de sincronización (la carpeta ahora se llama sincronización)
//include_once('sincronizacion/cargar_fichero_generico.php');
//include_once('sincronizacion/generar_ficheros_exportacion.php');
//include_once('sincronizacion/borrar_ficheros_antiguos.php');
/*
$contenido = ob_get_clean();
if ($fichero = fopen('/home/dpfevaristo/public_html/log.html', 'a+')){
	fputs($fichero, $contenido);
	fclose($fichero);
}
*/
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
    <head>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
        <title>Inserción de elementos</title>
    </head>
    <body>
		<p>Sincronización de elementos</p>
        <?php

		//Primero importamos
		$sincronizador = new ArmiSync(true);
		$sincronizador->fullImport();
		
		//Ahora viene la exportación
		//Nos empezamos asegurando de que los códigos de Sinlib de los clientes se propaguen a los pedidos
		//PedidoCliente::associateEmptyClientsCode();
		//Ahora ejecutamos la exportación
		$sincronizador = new ArmiSync(true);
		//Indicamos el juego de caracteres de conversión
		$sincronizador->setEncodingOutput(array('UTF-8//IGNORE', 'ISO-8859-1'));
		//Primero de clientes
		//$sincronizador->generar_fichero_usuario();	==> Sólo se generan los ficheros de pedido de clientes (Pedro 28/05/2019)
		//Ahora de pedidos
		//echo("Tratamos de generar los ficheros de pedidos<br />\n");
		//$sincronizador->generar_fichero_pedido();

		//Marina(10/diciembre/2019) vamos a llamar a la funcion que exporta los datos
		$sincronizador->exportPendingData(array('Usuario', 'PedidoCliente', 'LineaPedidoCliente'));
		//$sincronizador->exportPendingData(array('Usuario'));
		//Por último borramos ficheros antiguos
		ArmiSync::cleanOldFiles('finished/', 10);
		ArmiSync::cleanOldFiles('logs/', 10);


        ?>
    </body>
</html>
